@@ -1,4 +1,4 @@
-# $Id: input.rb 576 2010-04-11 14:52:02Z helixblue $
+# $Id: input.rb 606 2010-08-08 04:09:06Z helixblue $
 
 class Input
   include Common
@@ -154,8 +154,10 @@ class Input
     cmdline = "geotoad.rb"
     @@optHash.keys.sort.each { |option|
       if (option != 'queryArg') && (option != 'outDir') && (option != 'outFile') && @@optHash[option]
-        if (@@optHash[option] == 'X')
+        if @@optHash[option] == 'X'
           cmdline = cmdline + " --#{option}"
+        elsif @@optHash[option] == ''
+          cmdline = cmdline
         else
           # Omit the quotes if the argument is 'simple'
           if @@optHash[option].to_s =~ /^[\w\.:]+$/
